#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 data-default
version:              0.7.1.3
visibility:           public
id:                   data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz
key:                  data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz
license:              BSD-3-Clause
copyright:            (c) 2013 Lukas Mai
maintainer:           <lukasmai.403+hackage@gmail.com>
author:               Lukas Mai
synopsis:             A class for types with a default value
description:
    This module defines a class for types with a default value. Instances are
    provided for '\''()'\'', '\''Data.Set.Set'\'', '\''Data.Map.Map'\'', '\''Int'\'', '\''Integer'\'',
    '\''Float'\'', '\''Double'\'', and many others.

category:             Data
abi:                  b8841372a7f112a811f4029d7ba506c2
exposed:              True
exposed-modules:      Data.Default
import-dirs:          /usr/lib/ghc-9.6.6/site-local/data-default-0.7.1.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/data-default-0.7.1.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/data-default-0.7.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-default
hs-libraries:         HSdata-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz
depends:
    base-4.18.2.1 data-default-class-0.1.2.2-CDKXYK1wrFx3d5as0Pbjkc
    data-default-instances-containers-0.1.0.3-8ELlrcZVmwsaz5lkNw4uJ
    data-default-instances-dlist-0.0.1.2-6l3LZ8eMpsSDLzRhm8kcWB
    data-default-instances-old-locale-0.0.1.2-9CSNf5ZhfrnBXnsnQcXWXE

haddock-interfaces:
    /usr/share/doc/haskell-data-default/html/data-default.haddock

haddock-html:         /usr/share/doc/haskell-data-default/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

